==> gulp-lcov-to-html-0.0.3.tgz: package/lib/index.js <==
var PLUGIN_NAME, format, fs, generate, gutil, parser, path, sass, through;

fs = require("fs");

path = require("path");

format = require("dateformat");

through = require("through2");

gutil = require("gulp-util");

sass = require("node-sass");

parser = require('./parser.js');

generate = require('./generate.js');

PLUGIN_NAME = "gulp-lcov-genhtml";

module.exports = function(options) {
  var didOutputFiles, gatherFiles, generateHTML;
  if (options == null) {
    options = {};
  }
  didOutputFiles = false;
  gatherFiles = function(file, enc, cb) {
    var i, len, parsedData, ref;
    if (file.isNull()) {
      return cb(null, file);
    }
    if (file.isStream()) {
      return cb(new gutil.PluginError(PLUGIN_NAME, "Streams are not supported"));
    }
    parsedData = parser(file.contents.toString(enc));
    if (parsedData == null) {
      return cb(new gutil.PluginError(PLUGIN_NAME, "Incorrectly formatted lcov file: " + file.path));
    }
    if (parsedData.name == null) {
      parsedData.name = options.name;
    }
    parsedData.date = format(file.stat.ctime, "yyyy-mm-dd");
    ref = generate(parsedData);
    for (i = 0, len = ref.length; i < len; i++) {
      file = ref[i];
      didOutputFiles = true;
      this.push(file);
    }
    return cb();
  };
  generateHTML = function(cb) {
    if (!didOutputFiles) {
      return cb();
    }
    return sass.render({
      file: path.resolve(__dirname, path.join("..", "templates", "css", "classic.scss"))
    }, (function(_this) {
      return function(err, data) {
        if (err != null) {
          cb(err);
        }
        _this.push(new gutil.File({
          path: "classic.css",
          contents: data.css
        }));
        return cb();
      };
    })(this));
  };
  return through.obj(gatherFiles, generateHTML);
};

==> gulp-lcov-to-html-2.0.0.tgz: package/lib/index.js <==
var PLUGIN_NAME, format, fs, generate, gutil, parser, path, sass, through;

fs = require("fs");

path = require("path");

format = require("dateformat");

through = require("through2");

gutil = require("gulp-util");

sass = require("node-sass");

parser = require('./parser.js');

generate = require('./generate.js');

PLUGIN_NAME = "gulp-lcov-genhtml";

module.exports = function(options) {
  var gatherFiles, generateHTML, lcovData;
  if (options == null) {
    options = {};
  }
  lcovData = null;
  gatherFiles = function(file, enc, cb) {
    var parseResults;
    if (file.isNull()) {
      return cb(null, file);
    }
    if (file.isStream()) {
      return cb(new gutil.PluginError(PLUGIN_NAME, "Streams are not supported"));
    }
    parseResults = parser(file.contents.toString(enc), lcovData != null ? lcovData.files : void 0);
    if (parseResults == null) {
      return cb(new gutil.PluginError(PLUGIN_NAME, "Incorrectly formatted lcov file: " + file.path));
    }
    if (lcovData == null) {
      lcovData = parseResults;
    }
    if (lcovData.date == null) {
      lcovData.date = format(file.stat.ctime, "yyyy-mm-dd");
    }
    return cb();
  };
  generateHTML = function(cb) {
    var file, i, len, ref, ref1;
    if (!lcovData) {
      return cb();
    }
    lcovData.name = (ref = options.name) != null ? ref : lcovData.name;
    ref1 = generate(lcovData);
    for (i = 0, len = ref1.length; i < len; i++) {
      file = ref1[i];
      this.push(file);
    }
    return sass.render({
      file: path.resolve(__dirname, path.join("..", "templates", "css", "classic.scss"))
    }, (function(_this) {
      return function(err, data) {
        if (err != null) {
          cb(err);
        }
        _this.push(new gutil.File({
          path: "classic.css",
          contents: data.css
        }));
        return cb();
      };
    })(this));
  };
  return through.obj(gatherFiles, generateHTML);
};
